.. bpack documentation master file, created by
   sphinx-quickstart on Sun Nov 29 10:40:46 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. title and metadata

.. include:: bpack.rst
   :end-before: .. toctree::

.. description

.. include:: ../README.rst
  :start-after: .. badges
  :end-before: .. local-definitions

.. |struct| replace:: :mod:`struct`


Documentation
=============

.. toctree::
   :maxdepth: 2

   overview
   installation
   userguide
   api/bpack
   development
   license
   release_notes
   indices
